6.3. setupjavax.build_jy — setupjavax documentation

# 6.3. setupjavax.build_jy

## 6.3.1. Module

Compiles Python and Java modules required for Jython.

Supports default standard paths only.

## 6.3.2. BuildJy

class `setupjavax.build_jy.` `BuildJy`(dist, **kw)

  Extends ‘build_py’ for compilation of Python and Java modules for Jython.

### 6.3.2.1. finalize_options

`BuildJy.` `finalize_options`()

  Set final values for all the options that this command supports. This is always called as late as possible, ie. after any option assignments from the command-line or from other commands have been done. Thus, this is the place to code option dependencies: if ‘foo’ depends on ‘bar’, then it is safe to set ‘foo’ from ‘bar’ as long as ‘foo’ still has the same value it was assigned in ‘initialize_options()’.

  This method must be implemented by all command classes.

### 6.3.2.2. initialize_options

`BuildJy.` `initialize_options`()

  Set default values for all the options that this command supports. Note that these defaults may be overridden by other commands, by the setup script, by config files, or by the command-line. Thus, this is not the place to code dependencies between options; generally, ‘initialize_options()’ implementations are just a bunch of “self.foo = None” assignments.

  This method must be implemented by all command classes.

### 6.3.2.3. run

`BuildJy.` `run`()

  Run command.

## 6.3.3. Exceptions

exception `setupjavax.build_jy.` `SetuplibBuildJyError`